@@ -180,13 +180,15 @@ class Executor:
 
             logger.debug(f'cleaning up instance (job_id: {job_id}, instance_id: {instance_id}, process: {process})')
 
-            if terminate:
-                logger.debug(f'terminating process')
-                try:
-                    process.terminate()
-                except Exception as e:
-                    logger.exception(e)
-            process.join(timeout=2)
+            if process.is_alive():
+                if terminate:
+                    logger.debug(f'terminating process')
+                    try:
+                        process.terminate()
+                    except Exception as e:
+                        logger.exception(e)
+                process.join(timeout=2)
+
             if not process.is_alive():
                 process.close()
                 logger.debug('process closed')
