@@ -129,7 +129,7 @@ class SqlAlchemyJobStore(JobStore):
 
     @db_user
     def get_jobs(self, pattern: str = None, session=None) -> List[Job]:
-        db_jobs = session.query(DbJob).all()
+        db_jobs = session.query(DbJob).all().order_by(DbJob.next_run_time.asc())
 
         if pattern is not None:
             compiled_pattern = re.compile(pattern)
